# Git Checkout
Quickly checkout your most recent branch!

<a href="https://asciinema.org/a/ByGs7AeXHOlUMIKMjHmM7N9k5" target="_blank"><img src="https://asciinema.org/a/ByGs7AeXHOlUMIKMjHmM7N9k5.png" /></a>

## Installation
Requirements: Python 3.*
```
wget -L https://git.io/fNfqh -O- | bash
```

## Usage
```
git ch  # checkout a branch
git mg  # merge a branch into current branch
git dl  # delete branches

# or use the commands directly
gitcheckout checkout
gitcheckout merge
gitcheckout delete
```

## TODO
- [x] Add GIF
- [x] Add tests
- [x] Bash script to install
- [x] Add delete support
- [x] Add merge support
- [ ] Remote support